You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jackrabbit.apache.org by tr...@apache.org on 2005/04/15 15:27:50 UTC

svn commit: r161452 - in incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core: nodetype/ nodetype/virtual/ observation/ version/ version/persistence/

Author: tripod
Date: Fri Apr 15 06:27:46 2005
New Revision: 161452

URL: http://svn.apache.org/viewcvs?view=rev&rev=161452
Log:
- fixing javadoc comments

Modified:
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDef.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefinitionImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDef.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefId.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefinitionImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeTypeManagerImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDef.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefId.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropertyDefinitionImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/virtual/VirtualNodeTypeStateManager.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/observation/DelegatingObservationDispatcher.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/VersionManager.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenNodeImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenVHImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalVersionImpl.java
    incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/PersistentNode.java

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDef.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDef.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDef.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDef.java Fri Apr 15 06:27:46 2005
@@ -20,7 +20,7 @@
 import org.apache.jackrabbit.core.Constants;
 
 /**
- * This interface define the base for item definitions.
+ * This interface defines the base for item definitions.
  */
 public interface ItemDef  {
 
@@ -42,38 +42,40 @@
     public QName getDeclaringNodeType();
 
     /**
-     * Returns the auto created flag.
-     * @return the auto created flag.
+     * Returns the 'autoCreated' flag.
+     * @return the 'autoCreated' flag.
      */
     public boolean isAutoCreated();
 
     /**
-     * Returns the on-parent-version attribute.
-     * @return the on-parent-version attribute.
+     * Returns the 'onParentVersion' attribute.
+     * @return the 'onParentVersion' attribute.
      */
     public int getOnParentVersion();
 
     /**
-     * Returns the protected flag.
-     * @return the protected flag.
+     * Returns the 'protected' flag.
+     * @return the 'protected' flag.
      */
     public boolean isProtected();
 
     /**
-     * Returns the mandatory flag.
-     * @return the mandatory flag.
+     * Returns the 'mandatory' flag.
+     * @return the 'mandatory' flag.
      */
     public boolean isMandatory();
 
     /**
-     * Returns if this is a residual definition.
-     * @return if this is a residual definition.
+     * Checks if this item definition is a residual definition.
+     * @return <code>true</code> if this is a residual definition;
+     *         <code>false</code> otherwise.
      */
     public boolean definesResidual();
 
     /**
-     * Returns if this is a node definition.
-     * @return if this is a node definition.
+     * Checks if this is a node definition.
+     * @return <code>true</code> if this is a node definition;
+     *         <code>false</code> otherwise, i.e. this is a property definition.
      */
     public boolean definesNode();
 }

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefImpl.java Fri Apr 15 06:27:46 2005
@@ -21,43 +21,44 @@
 import javax.jcr.version.OnParentVersionAction;
 
 /**
- * This class is an abstract imlementation for the ChildItemDef interface and
- * hold the generic item def attributes.
+ * This class is an abstract implementation for the <code>ItemDef</code>
+ * interface and holds the generic item definition attributes.
  */
 public abstract class ItemDefImpl implements ItemDef {
 
     /**
-     * the name of this item def
+     * The name of this item definition.
      */
     private QName name = ANY_NAME;
 
     /**
-     * the name of the declaring node type
+     * The name of the declaring node type.
      */
     protected QName declaringNodeType = null;
 
     /**
-     * 'autocreate' flag
+     * The 'autoCreated' flag.
      */
     private boolean autoCreated = false;
 
     /**
-     * on parent version attribute
+     * The 'onParentVersion' attribute.
      */
     private int onParentVersion = OnParentVersionAction.COPY;
 
     /**
-     * write protected flag
+     * The 'writeProtected' flag.
      */
     private boolean writeProtected = false;
 
     /**
-     * mandatory flag
+     * The 'mandatory' flag.
      */
     private boolean mandatory = false;
 
     /**
      * Sets the declaring node type.
+     *
      * @param declaringNodeType
      */
     public void setDeclaringNodeType(QName declaringNodeType) {
@@ -68,7 +69,8 @@
     }
 
     /**
-     * Sets the name
+     * Sets the name.
+     *
      * @param name
      */
     public void setName(QName name) {
@@ -79,7 +81,8 @@
     }
 
     /**
-     * Sets the auto create flag
+     * Sets the auto create flag.
+     *
      * @param autoCreated
      */
     public void setAutoCreated(boolean autoCreated) {
@@ -87,7 +90,8 @@
     }
 
     /**
-     * Sets the on parent version
+     * Sets the on parent version.
+     *
      * @param onParentVersion
      */
     public void setOnParentVersion(int onParentVersion) {
@@ -95,7 +99,8 @@
     }
 
     /**
-     * Sets the protected flag
+     * Sets the protected flag.
+     *
      * @param writeProtected
      */
     public void setProtected(boolean writeProtected) {
@@ -103,7 +108,8 @@
     }
 
     /**
-     * sets the mandatory flag
+     * Sets the mandatory flag.
+     *
      * @param mandatory
      */
     public void setMandatory(boolean mandatory) {
@@ -160,12 +166,12 @@
     }
 
     /**
-     * checks if this child item def is equal to the given one. two itemdefs
-     * are equal if they are the same object or if all their attributes are
-     * equal.
+     * Checks if this item definition is equal to the given one. Two item
+     * definitions are equal if they are the same object or if all their
+     * attributes are equal.
      *
      * @param obj the object to compare to
-     * @return <code>true</code> if this item def is equal to obj;
+     * @return <code>true</code> if this item definition is equals to obj;
      *         <code>false</code> otherwise.
      */
     public boolean equals(Object obj) {
@@ -174,7 +180,9 @@
         }
         if (obj instanceof ItemDefImpl) {
             ItemDefImpl other = (ItemDefImpl) obj;
-            return (declaringNodeType == null ? other.declaringNodeType == null : declaringNodeType.equals(other.declaringNodeType))
+            return (declaringNodeType == null
+                        ? other.declaringNodeType == null
+                        : declaringNodeType.equals(other.declaringNodeType))
                     && (name == null ? other.name == null : name.equals(other.name))
                     && autoCreated == other.autoCreated
                     && onParentVersion == other.onParentVersion
@@ -183,6 +191,4 @@
         }
         return false;
     }
-
-
 }

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefinitionImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefinitionImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefinitionImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/ItemDefinitionImpl.java Fri Apr 15 06:27:46 2005
@@ -26,32 +26,32 @@
 import javax.jcr.nodetype.ItemDefinition;
 
 /**
- * this class implements the ItemDef interface
+ * This class implements the <code>ItemDefinition</code> interface.
  */
 abstract class ItemDefinitionImpl implements ItemDefinition {
 
     /**
-     * the default logger
+     * The default logger.
      */
     private static Logger log = Logger.getLogger(ItemDefImpl.class);
 
     /**
-     * Literal for 'any name'
+     * Literal for 'any name'.
      */
     protected static final String ANY_NAME = "*";
 
     /**
-     * the node type manager of this session
+     * The node type manager of this session.
      */
     protected final NodeTypeManagerImpl ntMgr;
 
     /**
-     * namespace resolver used to translate qualified names to JCR names
+     * The namespace resolver used to translate qualified names to JCR names.
      */
     protected final NamespaceResolver nsResolver;
 
     /**
-     * the underlaying child item def
+     * The underlying child item definition.
      */
     protected final ItemDef itemDef;
 
@@ -62,14 +62,15 @@
      * @param ntMgr      node type manager
      * @param nsResolver namespace resolver
      */
-    ItemDefinitionImpl(ItemDef itemDef, NodeTypeManagerImpl ntMgr, NamespaceResolver nsResolver) {
+    ItemDefinitionImpl(ItemDef itemDef, NodeTypeManagerImpl ntMgr,
+                       NamespaceResolver nsResolver) {
         this.itemDef = itemDef;
         this.ntMgr = ntMgr;
         this.nsResolver = nsResolver;
     }
 
     /**
-     * Returns the qname of this item def
+     * Returns the qualified name of this item definition.
      *
      * @return
      */
@@ -77,7 +78,7 @@
         return itemDef.getName();
     }
 
-    //--------------------------------------------------------------< ItemDef >
+    //-----------------------------------------------------< ItemDefinition >---
     /**
      * {@inheritDoc}
      */

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDef.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDef.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDef.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDef.java Fri Apr 15 06:27:46 2005
@@ -19,13 +19,13 @@
 import org.apache.jackrabbit.core.QName;
 
 /**
- * This interface define a ChilsNodeDefinition
+ * This interface defines a node definition.
  */
 public interface NodeDef extends ItemDef {
 
     /**
-     * Returns the nodedef id of this node def.
-     * @return the node def id.
+     * Returns the id of this node definition.
+     * @return the id of this node definition.
      */
     public NodeDefId getId();
 
@@ -42,8 +42,8 @@
     public QName[] getRequiredPrimaryTypes();
 
     /**
-     * Returns the 'allowSameNameSiblings' flag.
-     * @return the 'allowSameNameSiblings' flag.
+     * Returns the 'allowsSameNameSiblings' flag.
+     * @return the 'allowsSameNameSiblings' flag.
      */
     public boolean allowsSameNameSiblings();
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefId.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefId.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefId.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefId.java Fri Apr 15 06:27:46 2005
@@ -28,12 +28,12 @@
 public class NodeDefId implements Serializable {
 
     /**
-     * the serial number
+     * the serial number.
      */
     static final long serialVersionUID = 7020286139887664713L;
 
     /**
-     * the internal id
+     * The internal id.
      */
     private final int id;
 
@@ -68,7 +68,7 @@
     }
 
     /**
-     * Private constructor that creates an NodeDefId from an internal id
+     * Private constructor that creates an NodeDefId using an internal id
      * @param id
      */
     private NodeDefId(int id) {
@@ -119,7 +119,7 @@
      * {@inheritDoc}
      */
     public int hashCode() {
-        // id is already the computed hash code
+        // the computed 'id' is used as hash code
         return id;
     }
 }

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefinitionImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefinitionImpl.java Fri Apr 15 06:27:46 2005
@@ -26,17 +26,17 @@
 import javax.jcr.nodetype.NodeDefinition;
 
 /**
- * This class implements the NodeDef interface.
+ * This class implements the <code>NodeDefinition</code> interface.
  */
 public class NodeDefinitionImpl extends ItemDefinitionImpl implements NodeDefinition {
 
     /**
-     * the default logger
+     * The default logger.
      */
     private static Logger log = Logger.getLogger(NodeDefImpl.class);
 
     /**
-     * Package private constructor
+     * Package private constructor.
      *
      * @param nodeDef    child node definition
      * @param ntMgr      node type manager
@@ -48,14 +48,16 @@
     }
 
     /**
-     * Returns the underlaying item def
-     * @return
+     * Returns the underlying node definition.
+     *
+     * @return the underlying node definition.
      */
     public NodeDef unwrap() {
         return (NodeDef) itemDef;
     }
 
-    //--------------------------------------------------------------< NodeDef >
+    //-----------------------------------------------------< NodeDefinition >---
+
     /**
      * {@inheritDoc}
      */

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeTypeManagerImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeTypeManagerImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeTypeManagerImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeTypeManagerImpl.java Fri Apr 15 06:27:46 2005
@@ -42,34 +42,40 @@
         NodeTypeRegistryListener {
 
     /**
-     * the default logger
+     * The default logger.
      */
     private static Logger log = Logger.getLogger(NodeTypeManagerImpl.class);
 
     /**
-     * the underlaying node type registry
+     * The underlying node type registry.
      */
     private final NodeTypeRegistry ntReg;
 
+    /**
+     * The root node definition.
+     */
     private final NodeDefinitionImpl rootNodeDef;
 
     /**
-     * namespace resolver used to translate qualified names to JCR names
+     * The namespace resolver used to translate qualified names to JCR names.
      */
     private final NamespaceResolver nsResolver;
 
     /**
-     * A cache for <code>NodeType</code> instances created by this <code>NodeTypeManager</code>
+     * A cache for <code>NodeType</code> instances created by this
+     * <code>NodeTypeManager</code>
      */
     private final Map ntCache;
 
     /**
-     * A cache for <code>PropertyDef</code> instances created by this <code>NodeTypeManager</code>
+     * A cache for <code>PropertyDefinition</code> instances created by this
+     * <code>NodeTypeManager</code>
      */
     private final Map pdCache;
 
     /**
-     * A cache for <code>NodeDef</code> instances created by this <code>NodeTypeManager</code>
+     * A cache for <code>NodeDefinition</code> instances created by this
+     * <code>NodeTypeManager</code>
      */
     private final Map ndCache;
 
@@ -159,7 +165,7 @@
         return ntReg;
     }
 
-    //---------------------------------------------< NodeTypeRegistryListener >
+    //-------------------------------------------< NodeTypeRegistryListener >---
     /**
      * {@inheritDoc}
      */
@@ -189,7 +195,7 @@
         ndCache.clear();
     }
 
-    //------------------------------------------------------< NodeTypeManager >
+    //----------------------------------------------------< NodeTypeManager >---
     /**
      * {@inheritDoc}
      */
@@ -245,7 +251,7 @@
         }
     }
 
-    //----------------------------------------------------------< diagnostics >
+    //--------------------------------------------------------< diagnostics >---
     /**
      * Dumps the state of this <code>NodeTypeManager</code> instance.
      *
@@ -258,7 +264,7 @@
         ntReg.dump(ps);
     }
 
-    //--------------------------------------------------------< inner classes >
+    //------------------------------------------------------< inner classes >---
     /**
      * The <code>RootNodeDefinition</code> defines the characteristics of
      * the root node.

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDef.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDef.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDef.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDef.java Fri Apr 15 06:27:46 2005
@@ -19,31 +19,31 @@
 import org.apache.jackrabbit.core.InternalValue;
 
 /**
- * This interface defines the property def.
+ * This interface defines a property definition.
  */
 public interface PropDef extends ItemDef {
 
     /**
-     * Returns the property definition id.
-     * @return the PropDefId
+     * Returns the id of this property definition.
+     * @return the id of this property definition.
      */
     public PropDefId getId();
 
     /**
-     * Returns the required type
-     * @return the required type
+     * Returns the required type.
+     * @return the required type.
      */
     public int getRequiredType();
 
     /**
-     * Returns the array of value constraints
-     * @return the array of value constraints
+     * Returns the array of value constraints.
+     * @return the array of value constraints.
      */
     public ValueConstraint[] getValueConstraints();
 
     /**
-     * Returns the array of default values
-     * @return the array of default values
+     * Returns the array of default values.
+     * @return the array of default values.
      */
     public InternalValue[] getDefaultValues();
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefId.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefId.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefId.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefId.java Fri Apr 15 06:27:46 2005
@@ -30,7 +30,7 @@
     static final long serialVersionUID = 3675238890036653593L;
 
     /**
-     * the internal id
+     * The internal id
      */
     private final int id;
 
@@ -112,7 +112,7 @@
      * {@inheritDoc}
      */
     public int hashCode() {
-        // id is already the computed hash code
+        // the computed 'id' is used as hash code
         return id;
     }
 }

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropDefImpl.java Fri Apr 15 06:27:46 2005
@@ -23,12 +23,13 @@
 import java.util.Arrays;
 
 /**
- * this class implements the PropDef interface.
+ * This class implements the <code>PropDef</code> interface and holds the
+ * property definition specific attributes.
  */
 public class PropDefImpl extends ItemDefImpl implements PropDef {
 
     /**
-     * The required type
+     * The required type.
      */
     private int requiredType = PropertyType.UNDEFINED;
 
@@ -38,17 +39,17 @@
     private ValueConstraint[] valueConstraints = ValueConstraint.EMPTY;
 
     /**
-     * the default values
+     * The default values.
      */
     private InternalValue[] defaultValues = InternalValue.EMPTY;
 
     /**
-     * the 'multiple' flag
+     * The 'multiple' flag
      */
     private boolean multiple = false;
 
     /**
-     * the id of this property def
+     * The id of this property definition.
      */
     private PropDefId id;
 
@@ -59,32 +60,32 @@
      */
     public void setRequiredType(int requiredType) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         this.requiredType = requiredType;
     }
 
     /**
-     * Sets the value constraints
+     * Sets the value constraints.
      *
      * @param valueConstraints
      */
     public void setValueConstraints(ValueConstraint valueConstraints[]) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         this.valueConstraints =
                 (valueConstraints == null) ? ValueConstraint.EMPTY : valueConstraints;
     }
 
     /**
-     * Sets the default values
+     * Sets the default values.
      *
      * @param defaultValues
      */
     public void setDefaultValues(InternalValue[] defaultValues) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         this.defaultValues =
                 (defaultValues == null) ? InternalValue.EMPTY : defaultValues;
@@ -97,7 +98,7 @@
      */
     public void setMultiple(boolean multiple) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         this.multiple = multiple;
     }
@@ -107,7 +108,7 @@
      */
     public void setDeclaringNodeType(QName declaringNodeType) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setDeclaringNodeType(declaringNodeType);
     }
@@ -117,7 +118,7 @@
      */
     public void setName(QName name) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setName(name);
     }
@@ -127,7 +128,7 @@
      */
     public void setAutoCreated(boolean autoCreated) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setAutoCreated(autoCreated);
     }
@@ -137,7 +138,7 @@
      */
     public void setOnParentVersion(int onParentVersion) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setOnParentVersion(onParentVersion);
     }
@@ -147,7 +148,7 @@
      */
     public void setProtected(boolean writeProtected) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setProtected(writeProtected);
     }
@@ -157,7 +158,7 @@
      */
     public void setMandatory(boolean mandatory) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. PropDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Property definition already compiled.");
         }
         super.setMandatory(mandatory);
     }
@@ -208,9 +209,13 @@
     }
 
     /**
-     * Checks if this prop def is equal to the given one.
+     * Checks if this property definition is equal to the given one. Two
+     * property definitions are equal if they are the same object or if all
+     * their attributes are equal.
+     *
      * @param obj the object to compare to
-     * @return <code>true</code> if equals; <code>false</code> otherwise
+     * @return <code>true</code> if this property definition is equals to obj;
+     *         <code>false</code> otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropertyDefinitionImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropertyDefinitionImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropertyDefinitionImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/PropertyDefinitionImpl.java Fri Apr 15 06:27:46 2005
@@ -25,12 +25,12 @@
 import javax.jcr.nodetype.PropertyDefinition;
 
 /**
- * This class implements the PropertyDef interface.
+ * This class implements the <code>PropertyDefinition</code> interface.
  */
 public class PropertyDefinitionImpl extends ItemDefinitionImpl implements PropertyDefinition {
 
     /**
-     * the default logger
+     * The default logger.
      */
     private static Logger log = Logger.getLogger(PropertyDefinitionImpl.class);
 
@@ -41,19 +41,22 @@
      * @param ntMgr      node type manager
      * @param nsResolver namespace resolver
      */
-    PropertyDefinitionImpl(PropDef propDef, NodeTypeManagerImpl ntMgr, NamespaceResolver nsResolver) {
+    PropertyDefinitionImpl(PropDef propDef, NodeTypeManagerImpl ntMgr,
+                           NamespaceResolver nsResolver) {
         super(propDef, ntMgr, nsResolver);
     }
 
     /**
-     * Returns the underlaying prop def
-     * @return
+     * Returns the underlying property definition.
+     * 
+     * @return the underlying property definition.
      */
     public PropDef unwrap() {
         return (PropDef) itemDef;
     }
 
-    //----------------------------------------------------------< PropertyDef >
+    //-------------------------------------------------< PropertyDefinition >---
+
     /**
      * {@inheritDoc}
      */

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/virtual/VirtualNodeTypeStateManager.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/virtual/VirtualNodeTypeStateManager.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/virtual/VirtualNodeTypeStateManager.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/virtual/VirtualNodeTypeStateManager.java Fri Apr 15 06:27:46 2005
@@ -75,7 +75,7 @@
 
     /**
      * the delegtating observation manager, that dispatches the events to
-     * all underlaying ones.
+     * all underlying ones.
      */
     private DelegatingObservationDispatcher obsDispatcher;
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/observation/DelegatingObservationDispatcher.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/observation/DelegatingObservationDispatcher.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/observation/DelegatingObservationDispatcher.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/observation/DelegatingObservationDispatcher.java Fri Apr 15 06:27:46 2005
@@ -25,7 +25,7 @@
 
 /**
  * This Class implements an observation dispatcher, that delegates events to
- * a set of underlaying dispatchers.
+ * a set of underlying dispatchers.
  */
 public class DelegatingObservationDispatcher {
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/VersionManager.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/VersionManager.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/VersionManager.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/VersionManager.java Fri Apr 15 06:27:46 2005
@@ -28,7 +28,7 @@
 import java.util.List;
 
 /**
- * This interface defines the version manager. It gives access to the underlaying
+ * This interface defines the version manager. It gives access to the underlying
  * persistence layer of the versioning.
  */
 public interface VersionManager {

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenNodeImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenNodeImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenNodeImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenNodeImpl.java Fri Apr 15 06:27:46 2005
@@ -49,7 +49,7 @@
         implements InternalFrozenNode, Constants {
 
     /**
-     * the underlaying persistance node
+     * the underlying persistance node
      */
     private PersistentNode node;
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenVHImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenVHImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenVHImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalFrozenVHImpl.java Fri Apr 15 06:27:46 2005
@@ -33,7 +33,7 @@
 class InternalFrozenVHImpl extends InternalFreezeImpl implements InternalFrozenVersionHistory {
 
     /**
-     * the underlaying persistence node
+     * the underlying persistence node
      */
     private PersistentNode node;
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalVersionImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalVersionImpl.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalVersionImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/InternalVersionImpl.java Fri Apr 15 06:27:46 2005
@@ -50,7 +50,7 @@
     private ArrayList successors = new ArrayList();
 
     /**
-     * the underlaying persistance node of this version
+     * the underlying persistance node of this version
      */
     private PersistentNode node;
 

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/PersistentNode.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/PersistentNode.java?view=diff&r1=161451&r2=161452
==============================================================================
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/PersistentNode.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/version/persistence/PersistentNode.java Fri Apr 15 06:27:46 2005
@@ -41,7 +41,7 @@
 public class PersistentNode {
 
     /**
-     * the underlaying persistent state
+     * the underlying persistent state
      */
     private NodeState nodeState;
--- incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefImpl.java (original)
+++ incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefImpl.java Fri Apr 15 06:27:46 2005
@@ -22,28 +22,28 @@
 import java.util.Arrays;
 
 /**
  * This class implements the ChildNodeDef interface. It basically holds the
  * respective attributes.
  */
 public class NodeDefImpl extends ItemDefImpl implements NodeDef {
 
     /**
-     * the name of the default primary type
+     * The name of the default primary type.
      */
     private QName defaultPrimaryType = null;
 
     /**
-     * the names of the required primary types
+     * The names of the required primary types.
      */
     private QName[] requiredPrimaryTypes = new QName[]{Constants.NT_BASE};
 
     /**
-     * the 'allowSameNameSibs' flag.
+     * The 'allowsSameNameSiblings' flag.
      */
     private boolean allowsSameNameSiblings = false;
 
     /**
-     * the node def id. Set after 'compile'
+     * The id of the node definition.
      */
     private NodeDefId id;
 
@@ -52,7 +52,7 @@
      */
     public void setDeclaringNodeType(QName declaringNodeType) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setDeclaringNodeType(declaringNodeType);
     }
@@ -62,7 +62,7 @@
      */
     public void setName(QName name) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setName(name);
     }
@@ -72,7 +72,7 @@
      */
     public void setAutoCreated(boolean autoCreated) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setAutoCreated(autoCreated);
     }
@@ -82,7 +82,7 @@
      */
     public void setOnParentVersion(int onParentVersion) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setOnParentVersion(onParentVersion);
     }
@@ -92,7 +92,7 @@
      */
     public void setProtected(boolean writeProtected) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setProtected(writeProtected);
     }
@@ -102,31 +102,31 @@
      */
     public void setMandatory(boolean mandatory) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         super.setMandatory(mandatory);
     }
 
     /**
-     * Sets the name of default primary type
+     * Sets the name of default primary type.
      *
      * @param defaultNodeType
      */
     public void setDefaultPrimaryType(QName defaultNodeType) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         this.defaultPrimaryType = defaultNodeType;
     }
 
     /**
-     * Sets the names of the required primary types
+     * Sets the names of the required primary types.
      *
      * @param requiredPrimaryTypes
      */
     public void setRequiredPrimaryTypes(QName[] requiredPrimaryTypes) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         if (requiredPrimaryTypes == null) {
             throw new IllegalArgumentException("requiredPrimaryTypes can not be null");
@@ -135,13 +135,13 @@
     }
 
     /**
-     * sets the 'allowsSameNameSiblings' flag
+     * Sets the 'allowsSameNameSiblings' flag.
      *
      * @param allowsSameNameSiblings
      */
     public void setAllowsSameNameSiblings(boolean allowsSameNameSiblings) {
         if (id != null) {
-            throw new IllegalStateException("Unable to set attribute. ChildNodeDef already compiled.");
+            throw new IllegalStateException("Unable to set attribute. Node definition already compiled.");
         }
         this.allowsSameNameSiblings = allowsSameNameSiblings;
     }
@@ -185,9 +185,13 @@
     }
 
     /**
-     * checks if this child node def is equal to the given one.
+     * Checks if this node definition is equal to the given one. Two node
+     * definitions are equal if they are the same object or if all their
+     * attributes are equal.
+     *
      * @param obj the other object to compare to.
-     * @return <code>true</code> if equal; <code>false</code> otherwise.
+     * @return <code>true</code> if this item definition is equals to obj;
+     *         <code>false</code> otherwise.
      */
     public boolean equals(Object obj) {
         if (this == obj) {
@@ -197,7 +201,9 @@
             NodeDefImpl other = (NodeDefImpl) obj;
             return super.equals(obj)
                     && Arrays.equals(requiredPrimaryTypes, other.requiredPrimaryTypes)
-                    && (defaultPrimaryType == null ? other.defaultPrimaryType == null : defaultPrimaryType.equals(other.defaultPrimaryType))
+                    && (defaultPrimaryType == null
+                            ? other.defaultPrimaryType == null
+                            : defaultPrimaryType.equals(other.defaultPrimaryType))
                     && allowsSameNameSiblings == other.allowsSameNameSiblings;
         }
         return false;
@@ -22,28 +22,28 @@
 
 /**
- * This class implements the ChildNodeDef interface. It basically holds the
- * respective attributes.
+ * This class implements the <code>NodeDef</code> interface and holds the node
+ * definition specific attributes.
  */
 public class NodeDefImpl extends ItemDefImpl implements NodeDef {

Modified: incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefinitionImpl.java
URL: http://svn.apache.org/viewcvs/incubator/jackrabbit/trunk/src/java/org/apache/jackrabbit/core/nodetype/NodeDefinitionImpl.java?view=diff&r1=161451&r2=161452
==============================================================================